OC.L10N.register(
    "logreader",
    {
    "Error parsing log" : "Грешка при парсирању дневника",
    "Copy" : "Копирај",
    "Copy raw" : "Копирај непрерађено",
    "Copy formatted" : "Копирај форматирано",
    "No server logs" : "Нема дневника на серверу",
    "One or more entries are hidden by the log level filter" : "Један или више уноса су скривени због нивоа филтрирања",
    "Everything is working fine" : "Све ради лепо",
    "Level" : "Ниво",
    "App" : "Апликација",
    "Message" : "Порука",
    "Time" : "Време",
    "Log levels" : "Нивои логовања",
    "Log content" : "Садржај дневника",
    "Live update" : "Ажурирање уживо",
    "Download logs" : "Скини дневнике",
    "Logging" : "Уписивање у дневник",
    "Log Reader" : "Читач дневника",
    "A log reader for Nextcloud" : "Читач дневника за Некстклауд",
    "Log reader for Nextcloud" : "Читач дневника за Некстклауд",
    "Cased by " : "Окружен са"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);");
